==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/ClusterResourceQuotaSelectorBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterResourceQuotaSelectorBuilder extends io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorFluentImpl<io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ClusterResourceQuotaSelector,io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorBuilder>{
  public ClusterResourceQuotaSelectorBuilder() {
    this(false);
  }
  public ClusterResourceQuotaSelectorBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterResourceQuotaSelector(), validationEnabled);
  }
  public ClusterResourceQuotaSelectorBuilder(io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterResourceQuotaSelectorBuilder(io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterResourceQuotaSelector(), validationEnabled);
  }
  public ClusterResourceQuotaSelectorBuilder(io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorFluent<?> fluent,io.fabric8.openshift.api.model.ClusterResourceQuotaSelector instance) {
    this(fluent, instance, false);
  }
  public ClusterResourceQuotaSelectorBuilder(io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorFluent<?> fluent,io.fabric8.openshift.api.model.ClusterResourceQuotaSelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAnnotations(instance.getAnnotations()); 
    fluent.withLabels(instance.getLabels()); 
    this.validationEnabled = validationEnabled; 
  }
  public ClusterResourceQuotaSelectorBuilder(io.fabric8.openshift.api.model.ClusterResourceQuotaSelector instance) {
    this(instance,false);
  }
  public ClusterResourceQuotaSelectorBuilder(io.fabric8.openshift.api.model.ClusterResourceQuotaSelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAnnotations(instance.getAnnotations()); 
    this.withLabels(instance.getLabels()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ClusterResourceQuotaSelector build() {
    ClusterResourceQuotaSelector buildable = new ClusterResourceQuotaSelector(fluent.getAnnotations(),fluent.getLabels());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterResourceQuotaSelectorBuilder that = (ClusterResourceQuotaSelectorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/ClusterResourceQuotaSelectorBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterResourceQuotaSelectorBuilder extends io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorFluentImpl<io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ClusterResourceQuotaSelector,io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorBuilder>{
  public ClusterResourceQuotaSelectorBuilder() {
    this(false);
  }
  public ClusterResourceQuotaSelectorBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterResourceQuotaSelector(), validationEnabled);
  }
  public ClusterResourceQuotaSelectorBuilder(io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterResourceQuotaSelectorBuilder(io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterResourceQuotaSelector(), validationEnabled);
  }
  public ClusterResourceQuotaSelectorBuilder(io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorFluent<?> fluent,io.fabric8.openshift.api.model.ClusterResourceQuotaSelector instance) {
    this(fluent, instance, false);
  }
  public ClusterResourceQuotaSelectorBuilder(io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorFluent<?> fluent,io.fabric8.openshift.api.model.ClusterResourceQuotaSelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAnnotations(instance.getAnnotations()); 
    fluent.withLabels(instance.getLabels()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterResourceQuotaSelectorBuilder(io.fabric8.openshift.api.model.ClusterResourceQuotaSelector instance) {
    this(instance,false);
  }
  public ClusterResourceQuotaSelectorBuilder(io.fabric8.openshift.api.model.ClusterResourceQuotaSelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAnnotations(instance.getAnnotations()); 
    this.withLabels(instance.getLabels()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ClusterResourceQuotaSelectorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ClusterResourceQuotaSelector build() {
    ClusterResourceQuotaSelector buildable = new ClusterResourceQuotaSelector(fluent.getAnnotations(),fluent.getLabels());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterResourceQuotaSelectorBuilder that = (ClusterResourceQuotaSelectorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
